==> genomes_1.4.0.tar.gz: genomes/R/updatevirus.R <==
updatevirus <- function()
{  
   url <- "http://www.ncbi.nlm.nih.gov/genomes/GenomesGroup.cgi?taxid=10239&opt=Virus&sort=genome&cmd=download"
   dtime <- system.time( prj <-  read.table(url, sep="\t", fill=TRUE, as.is=TRUE, quote="") )
   ##columns 5 and 10 are empty
   prj <- prj[,c(1:4,6:9)]  
   ## column names
   names(prj) <- c( "name", "refseq",   "isolate",  "segments" ,
                  "size", "proteins", "released", "neighbors")
   ## Released date
   prj$released <- as.Date(prj$released, "%m/%d/%Y")

   #  Virus table has segment details under expanded nodes  [-]  (closed by default on web page)
   #   refseq like NC*  - 1 segment
   #   refseq = '-'     - 2 or more segments
   #   refseq = ''      - segment details (segments are space delimited, so all data in 1st column)

   ### get accessions and sizes for mulit-segmented viruses
   n <- grep("^-$", prj$refseq)
   ## total segments (are segment counts ever wrong?)
   n2 <- as.numeric( prj$segments[n])
   n2 <- n2 + n
   ## loop through segments
   for( i in 1:length(n) )
   {
      x <- prj[ (n[i] +1 ) : n2[i],  1 ] 
      ## get ACCESSION numbers
      acc<-gsub("(.*)(NC_\\d*)(.*)", "\\2", x, perl=TRUE)
      ## get SIZEs
      sizes<-gsub("(.*?)(\\d+)( nt.*)", "\\2", x, perl=TRUE)
      ## add comman separated lists back to table
      prj$refseq[ n[i] ]<- paste(acc, collapse=",")
      prj$size[ n[i] ]<- paste(sizes, collapse=",")
   }

   ## drop segment details 
   prj <- subset(prj, prj$refseq != "")
     

   # segments=="-" are 1 segment
   prj$segments[prj$segments == "-"] <- 1
   class(prj$segments) <- "numeric"
   
   # neighbors =="-" are zero
   prj$neighbors[prj$neighbors == "-"] <- 0
   class(prj$neighbors) <- "numeric"

   #REMOVE nt from size 
   prj$size <- gsub(" nt", "", prj$size)

   ## proteins with "-"   - change to zero???
   prj$proteins[prj$proteins == "-"] <- 0
   class(prj$proteins) <- "numeric"

    ## trailing space on isolate names
   prj$isolate <- gsub(" $", "", prj$isolate)
   
   ## re-number rows (already alphabetical)
   row.names(prj) <- 1:nrow(prj)
   ## put  name, released in first 2 columns (for printing)
   prj <- prj[,c(1,7,8,4,2,3,5,6)]
   
   ## attributes
   class(prj) <- c("genomes", "data.frame")
   attr(prj, "url")    <- url
   attr(prj, "date")   <- Sys.Date()
   attr(prj, "stats")  <- paste( dim(prj)[1], "rows in" , round(dtime[3],1), "seconds")
   attr(prj, "update") <- "updatevirus()"
   prj
}

==> genomes_1.6.0.tar.gz: genomes/R/updatevirus.R <==
updatevirus <- function()
{  
   url <- "http://www.ncbi.nlm.nih.gov/genomes/GenomesGroup.cgi?taxid=10239&opt=Virus&sort=genome&cmd=download"
   dtime <- system.time( prj <-  read.table(url, sep="\t", fill=TRUE, as.is=TRUE, quote="") )
   ##columns 5 and 11 are empty
   prj <- prj[,c(1:4,6:10)]  
   ## column names
   names(prj) <- c( "name", "refseq",   "isolate",  "segments" ,
                  "size", "proteins", "neighbors", "released", "modified")
   ## Release and modified date
   prj$released <- as.Date(prj$released, "%m/%d/%Y")
   prj$modified <- as.Date(prj$modified, "%m/%d/%Y")
   
   #  Virus table has segment details under expanded nodes  [-]  (closed by default on web page)
   #   refseq like NC*  - 1 segment
   #   refseq = '-'     - 2 or more segments
   #   refseq = ''      - segment details (segments are space delimited, so all data in 1st column)

   ### get accessions and sizes for mulit-segmented viruses
   n <- grep("^-$", prj$refseq)
   ## total segments (are segment counts ever wrong?)
   n2 <- as.numeric( prj$segments[n])
   n2 <- n2 + n
   ## loop through segments
   for( i in 1:length(n) )
   {
      x <- prj[ (n[i] +1 ) : n2[i],  1 ] 
      ## get ACCESSION numbers
      acc<-gsub("(.*)(NC_\\d*)(.*)", "\\2", x, perl=TRUE)
      ## get SIZEs
      sizes<-gsub("(.*?)(\\d+)( nt.*)", "\\2", x, perl=TRUE)
      ## add comman separated lists back to table
      prj$refseq[ n[i] ]<- paste(acc, collapse=",")
      prj$size[ n[i] ]<- paste(sizes, collapse=",")
   }

   ## drop segment details 
   prj <- subset(prj, prj$refseq != "")
     

   # segments=="-" are 1 segment
   prj$segments[prj$segments == "-"] <- 1
   class(prj$segments) <- "numeric"
   
   # neighbors =="-" are zero
   prj$neighbors[prj$neighbors == "-"] <- 0
   class(prj$neighbors) <- "numeric"

   #REMOVE nt from size 
   prj$size <- gsub(" nt", "", prj$size)

   ## proteins with "-"   - change to zero???
   prj$proteins[prj$proteins == "-"] <- 0
   class(prj$proteins) <- "numeric"

    ## trailing space on isolate names
   prj$isolate <- gsub(" $", "", prj$isolate)
   
   ## re-number rows (already alphabetical)
   row.names(prj) <- 1:nrow(prj)
   ## put  name, released in first 2 columns (for printing)
   prj <- prj[,c(1,8,7,4,2,3,5,6, 9)]
   
   ## attributes
   class(prj) <- c("genomes", "data.frame")
   attr(prj, "url")    <- url
   attr(prj, "date")   <- Sys.Date()
   attr(prj, "stats")  <- paste( dim(prj)[1], "rows in" , round(dtime[3],1), "seconds")
   attr(prj, "update") <- "updatevirus()"
   prj
}
